@@ -11,7 +11,7 @@ from datetime import datetime
 
 from cubicweb import ValidationError
 from cubicweb.server.hook import Hook, Operation
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.server import hook
 
 from cubes.tracker import hooks as tracker
@@ -39,7 +39,7 @@ nosylist.O_RELS |= tracker.O_RELS
 class ChangeTicketStateOnVersionStatusChange(Hook):
     __regid__ = 'change_ticket_state_on_version_status_change'
     events = ('after_add_entity',)
-    __select__ = Hook.__select__ & implements('TrInfo')
+    __select__ = Hook.__select__ & is_instance('TrInfo')
 
     def __call__(self):
         forentity = self.entity.for_entity
@@ -47,24 +47,24 @@ class ChangeTicketStateOnVersionStatusChange(Hook):
             return
         if self.entity.new_state.name == 'published':
             for ticket in forentity.reverse_done_in:
-                if ticket.state == 'done':
+                iwf = ticket.cw_adapt_to('IWorkflowable')
+                if iwf.state == 'done':
                     msg = self._cw._('version published')
                     try:
-                        ticket.fire_transition('ask validation',
-                                               comment=msg,
-                                               commentformat=u'text/plain')
+                        iwf.fire_transition('ask validation',
+                                            comment=msg,
+                                            commentformat=u'text/plain')
                     except ValidationError, ex:
                         self.error('error while trying to change ticket state after version publishing: %s', ex)
 
 class AdjustPendingTicketState(Operation):
     def precommit_event(self):
-        if (self.ticket.state in ('done', 'validation pending') and
+        iwf = self.ticket.cw_adapt_to('IWorkflowable')
+        if (iwf.state in ('done', 'validation pending') and
             (not self.ticket.done_in
-             or self.ticket.done_in[0].state != 'published')):
+             or self.ticket.done_in[0].cw_adapt_to('IWorkflowable').state != 'published')):
             msg = self.session._('moved away from published version')
-            self.ticket.change_state('open',
-                                     comment=msg,
-                                     commentformat=u'text/plain')
+            iwf.change_state('open', comment=msg, commentformat=u'text/plain')
 
 
 class ChangeTicketStateOnDoneInChange(Hook):
@@ -74,17 +74,16 @@ class ChangeTicketStateOnDoneInChange(Hook):
     __select__ = Hook.__select__ & hook.match_rtype('done_in',)
 
     def __call__(self):
-        asession = self._cw.actual_session()
         ticket = self._cw.entity_from_eid(self.eidfrom)
         version = self._cw.entity_from_eid(self.eidto)
-        if ticket.state in ('done', 'validation pending'):
+        if ticket.cw_adapt_to('IWorkflowable').state in ('done', 'validation pending'):
             AdjustPendingTicketState(self._cw, ticket=ticket)
 
 
 class ResetLoadLeftOnTicketStatusChange(Hook):
     __regid__ = 'reset_load_left_on_ticket'
     events = ('after_add_entity',)
-    __select__ = Hook.__select__ & implements('TrInfo',)
+    __select__ = Hook.__select__ & is_instance('TrInfo',)
 
     def __call__(self):
         forentity = self.entity.for_entity
@@ -98,14 +97,14 @@ class ResetLoadLeftOnTicketStatusChange(Hook):
                 # also reset load in that case, we don't want initial estimation
                 # to be taken into account
                 attrs['load'] = 0
-            forentity.set_attributes(_cw_unsafe=True, **attrs)
+            forentity.set_attributes(**attrs)
 
 
 class SetTicketLoadLeft(Hook):
     """automatically set load_left according to load if unspecified"""
     __regid__ = 'set_ticket_load'
     events = ('before_add_entity', 'before_update_entity')
-    __select__ = Hook.__select__ & implements('Ticket',)
+    __select__ = Hook.__select__ & is_instance('Ticket',)
 
     def __call__(self):
         edited = self.entity.edited_attributes
@@ -126,16 +125,15 @@ class SetNosyListBeforeAddComment(Hook):
     def __call__(self):
         if self._cw.is_internal_session:
             return
-        asession = self._cw.actual_session()
         comment = self._cw.entity_from_eid(self.eidfrom)
-        entity = comment.root()
+        entity = comment.cw_adapt_to('ITree').root()
         if 'nosy_list' in entity.e_schema.subject_relations():
             x = entity.eid
         else:
             x = comment.eid
-        self._cw.unsafe_execute('SET X nosy_list U WHERE X eid %(x)s, U eid %(u)s, '
-                               'NOT X nosy_list U',
-                               {'x': x, 'u': asession.user.eid}, 'x')
+        self._cw.execute('SET X nosy_list U WHERE X eid %(x)s, U eid %(u)s, '
+                         'NOT X nosy_list U',
+                         {'x': x, 'u': self._cw.user.eid})
 
 
 class SetModificationDateAfterAddComment(Hook):
@@ -147,9 +145,8 @@ class SetModificationDateAfterAddComment(Hook):
     def __call__(self):
         entity = self._cw.entity_from_eid(self.eidto)
         while entity.e_schema == 'Comment':
-            entity = entity.root()
-        rql = 'SET X modification_date %(d)s WHERE X eid %(x)s'
-        self._cw.unsafe_execute(rql, {'x': entity.eid, 'd': datetime.now()}, 'x')
+            entity = entity.cw_adapt_to('ITree').root()
+        entity.set_attributes(modification_date=datetime.now())
 
 
 class TicketDoneInProgressHook(Hook):
@@ -164,7 +161,7 @@ class TicketDoneInProgressHook(Hook):
 
 class TicketProgressHook(Hook):
     __regid__ = 'ticket_progress'
-    __select__ = Hook.__select__ & implements('Ticket',)
+    __select__ = Hook.__select__ & is_instance('Ticket',)
     events = ('after_update_entity', )
 
     def __call__(self):
