@@ -6,7 +6,7 @@
 """
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.sobjects.notification import StatusChangeMixIn
 
 from cubes.tracker import sobjects as tracker
@@ -19,7 +19,7 @@ tracker.TicketSubmittedView.field_attrs.append('load')
 
 
 class ProjectStatusChangeView(StatusChangeMixIn, tracker.TrackerEmailView):
-    __select__ = implements('Project')
+    __select__ = is_instance('Project')
 
     def _subject(self, entity):
         return self._cw._(u'project is now in state "%s"') % (
@@ -38,7 +38,7 @@ class CommentAddedView(comment.CommentAddedView):
 
 class ProjectRecipientsFinder(nosylist.NosyListRecipientsFinder):
     __select__ = nosylist.NosyListRecipientsFinder.__select__ & \
-                 implements('Project')
+                 is_instance('Project')
 
     def recipients(self):
         entity = self.cw_rset.get_entity(0,0)
