@@ -4,17 +4,19 @@ from datetime import datetime, timedelta
 
 from logilab.common.testlib import unittest_main, mock_object
 
+from cubicweb.devtools import ApptestConfiguration
 from cubicweb.devtools.testlib import AutoPopulateTest
 
 from cubicweb import ValidationError
 from cubicweb import NoSelectableObject
-from cubicweb.web.views import actions, workflow
+from cubicweb.web.views import actions, workflow, idownloadable
 
 from cubes.tracker.testutils import TrackerBaseTC
 from cubes.tracker.views import ticket, document
 from cubes.comment import views as commentactions
 from cubes.forge.views import project as myproject, boxes
 from cubes.testcard import views as tcviews
+from cubes.nosylist import views as nosylist
 
 ONEDAY = timedelta(1)
 
@@ -41,7 +43,7 @@ class ProjectTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertRaises(NoSelectableObject,
                           self.vreg['boxes'].select, 'download_box', req, rset=rset)
-        v.change_state('published')
+        v.cw_adapt_to('IWorkflowable').change_state('published')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
@@ -64,6 +66,7 @@ class ProjectTC(TrackerBaseTC):
                                ('addrelated', actions.AddRelatedActions),
                                ('delete', actions.DeleteAction),
                                ('copy', actions.CopyAction),
+                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                                ('addticket', myproject.ProjectAddTicket),
                                ('addversion', myproject.ProjectAddVersion),
                                ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
@@ -75,14 +78,15 @@ class ProjectTC(TrackerBaseTC):
                                ])
         self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
                               [])
+        wf = self.cubicweb.cw_adapt_to('IWorkflowable').current_workflow
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('temporarily stop development').eid),
+                                wf.transition_by_name('temporarily stop development').eid),
                                (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('stop maintainance').eid),
+                                wf.transition_by_name('stop maintainance').eid),
                                (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('project moved').eid),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % self.cubicweb.current_workflow.eid)
+                                wf.transition_by_name('project moved').eid),
+                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
                                ])
         # logilab user
         self.create_user('logilabien', ('staff', 'users'))
@@ -107,12 +111,12 @@ class ProjectTC(TrackerBaseTC):
                               [])
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('temporarily stop development').eid),
+                                wf.transition_by_name('temporarily stop development').eid),
                                (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('stop maintainance').eid),
+                                wf.transition_by_name('stop maintainance').eid),
                                (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                self.cubicweb.current_workflow.transition_by_name('project moved').eid),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % self.cubicweb.current_workflow.eid)
+                                wf.transition_by_name('project moved').eid),
+                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
                                ])
         # guest user
         self.login('anon')
@@ -192,7 +196,7 @@ class ProjectTC(TrackerBaseTC):
                               [])
         # manager user, moved project
         self.restore_connection()
-        self.cubicweb.fire_transition('project moved')
+        self.cubicweb.cw_adapt_to('IWorkflowable').fire_transition('project moved')
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
@@ -203,6 +207,7 @@ class ProjectTC(TrackerBaseTC):
                                ('addrelated', actions.AddRelatedActions),
                                ('delete', actions.DeleteAction),
                                ('copy', actions.CopyAction),
+                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                                ('pvrestexport', document.ProjectVersionExportAction),
                                ])
         self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
@@ -238,17 +243,17 @@ class VersionTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         self.assertRaises(NoSelectableObject,
                           self.vreg['boxes'].select, 'download_box', req, rset=rset)
-        self.v.change_state('published')
+        self.v.cw_adapt_to('IWorkflowable').change_state('published')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
-                              boxes.VersionDownloadBox)
+                              idownloadable.DownloadBox)
         self.commit()
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Version, X num "0.0.0"')
         self.assertIsInstance(self.vreg['boxes'].select('download_box', req, rset=rset),
-                              boxes.VersionDownloadBox)
+                              idownloadable.DownloadBox)
 
 class TicketTC(TrackerBaseTC):
     """Ticket"""
@@ -264,14 +269,14 @@ class TicketTC(TrackerBaseTC):
 
     def test_load_after_state_changed_deprecated(self):
         self.t1.set_attributes(load=2)
-        self.t1.change_state('deprecated')
+        self.t1.cw_adapt_to('IWorkflowable').change_state('deprecated')
         self.commit()
         self.t1.pop('load', None)
         self.assertEquals(self.t1.load, 0)
 
     def test_load_after_state_changed_rejected(self):
         self.t1.set_attributes(load=2)
-        self.t1.change_state('rejected')
+        self.t1.cw_adapt_to('IWorkflowable').change_state('rejected')
         self.commit()
         self.t1.pop('load', None)
         self.assertEquals(self.t1.load, 0)
@@ -293,17 +298,17 @@ class TicketTC(TrackerBaseTC):
         olddate = datetime.today() - ONEDAY
         self.t1.set_attributes(modification_date=olddate)
         ceid = self.execute('INSERT Comment C: C content "A commment", C comments X '
-                            'WHERE X eid %(x)s', {'x': self.t1.eid}, 'x')[0][0]
+                            'WHERE X eid %(x)s', {'x': self.t1.eid})[0][0]
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
         self.t1.set_attributes(modification_date=olddate)
         ceid2 = self.execute('INSERT Comment C: C content "A commment", C comments X '
-                             'WHERE X eid %(x)s', {'x': ceid}, 'x')[0][0]
+                             'WHERE X eid %(x)s', {'x': ceid})[0][0]
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
         self.t1.set_attributes(modification_date=olddate)
         self.execute('INSERT Comment C: C content "A commment", C comments X '
-                     'WHERE X eid %(x)s', {'x': ceid2}, 'x')
+                     'WHERE X eid %(x)s', {'x': ceid2})
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
 
@@ -319,6 +324,7 @@ class TicketTC(TrackerBaseTC):
                               ('addrelated', actions.AddRelatedActions),
                               ('delete', actions.DeleteAction),
                               ('copy', actions.CopyAction),
+                              ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('movetonext', ticket.TicketMoveToNextVersionActions),
                               ('reply_comment', commentactions.AddCommentAction)])
         self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
@@ -328,18 +334,19 @@ class TicketTC(TrackerBaseTC):
                                ('add Card test_case_for Ticket object',
                                 'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid))])
+        wf = self.t1.cw_adapt_to('IWorkflowable').current_workflow
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'start', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('start').eid)),
+                                (self.t1.eid, wf.transition_by_name('start').eid)),
                                (u'reject', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('reject').eid)),
+                                (self.t1.eid, wf.transition_by_name('reject').eid)),
                                (u'done', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('done').eid)),
+                                (self.t1.eid, wf.transition_by_name('done').eid)),
                                (u'deprecate', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('deprecate').eid)),
+                                (self.t1.eid, wf.transition_by_name('deprecate').eid)),
                                (u'wait for feedback', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('wait for feedback').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % self.t1.current_workflow.eid)])
+                                (self.t1.eid, wf.transition_by_name('wait for feedback').eid)),
+                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)])
         movetonext = self.action_submenu(req, rset, 'movetonext')
         self.assertEquals(len(movetonext), 1)
         self.assertEquals(movetonext[0][0], '0.0.0')
@@ -356,7 +363,7 @@ class TicketTC(TrackerBaseTC):
                               [])
         self.restore_connection()
         req = self.request()
-        self.t1.fire_transition('done')
+        self.t1.cw_adapt_to('IWorkflowable').fire_transition('done')
         self.commit()
         rset = req.execute('Any X WHERE X is Ticket')
         self.failUnlessEqual(self.pactions(req, rset),
@@ -366,6 +373,7 @@ class TicketTC(TrackerBaseTC):
                               ('addrelated', actions.AddRelatedActions),
                               ('delete', actions.DeleteAction),
                               ('copy', actions.CopyAction),
+                              ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('reply_comment', commentactions.AddCommentAction)])
         self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
                               [('add Ticket attachment File subject',
@@ -376,10 +384,10 @@ class TicketTC(TrackerBaseTC):
                                 % (teid, teid))])
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'ask validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('ask validation').eid)),
+                                (self.t1.eid, wf.transition_by_name('ask validation').eid)),
                                (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('reopen').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % self.t1.current_workflow.eid),
+                                (self.t1.eid, wf.transition_by_name('reopen').eid)),
+                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
                                (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.login('anon')
         req = self.request()
@@ -393,17 +401,17 @@ class TicketTC(TrackerBaseTC):
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.restore_connection()
-        self.t1.fire_transition('ask validation')
+        self.t1.cw_adapt_to('IWorkflowable').fire_transition('ask validation')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         self.assertListEquals(self.action_submenu(req, rset, 'workflow'),
                               [(u'resolve', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('resolve').eid)),
+                                (self.t1.eid, wf.transition_by_name('resolve').eid)),
                                (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, self.t1.current_workflow.transition_by_name('reopen').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % self.t1.current_workflow.eid),
+                                (self.t1.eid, wf.transition_by_name('reopen').eid)),
+                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
                                (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
-        self.t1.fire_transition('resolve')
+        self.t1.cw_adapt_to('IWorkflowable').fire_transition('resolve')
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
@@ -414,6 +422,7 @@ class TicketTC(TrackerBaseTC):
                               ('addrelated', actions.AddRelatedActions),
                               ('delete', actions.DeleteAction),
                               ('copy', actions.CopyAction),
+                              ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('reply_comment', commentactions.AddCommentAction)])
         self.assertListEquals(self.action_submenu(req, rset, 'addrelated'),
                               [('add Ticket attachment File subject',
@@ -441,24 +450,26 @@ class TicketTC(TrackerBaseTC):
                           'WHERE P is Project').get_entity(0, 0)
         self.t1.set_relations(done_in=v2)
         self.commit()
-        self.t1.fire_transition('done')
+        t1iwf= self.t1.cw_adapt_to('IWorkflowable')
+        t1iwf.fire_transition('done')
         self.t1.clear_all_caches()
-        self.assertEquals(self.t1.state, 'done')
+        self.assertEquals(t1iwf.state, 'done')
         self.commit()
         v2.clear_all_caches()
         v2._cw = self.request()
-        self.assertEquals(v2.state, 'dev')
+        v2iwf = v2.cw_adapt_to('IWorkflowable')
+        self.assertEquals(v2iwf.state, 'dev')
         v2.clear_all_caches()
-        v2.change_state('published')
+        v2iwf.change_state('published')
         self.commit()
         self.t1.clear_all_caches()
-        self.assertEquals(self.t1.state, 'validation pending')
+        self.assertEquals(t1iwf.state, 'validation pending')
         # if the ticket is then moved to no version or to an unpublished version,
         # reopen it.
         self.t1.set_relations(done_in=self.v)
         self.commit()
         self.t1.clear_all_caches()
-        self.assertEquals(self.t1.state, 'open')
+        self.assertEquals(t1iwf.state, 'open')
 
     def test_version_publishing_cant_change_ticket_state(self):
         self.execute('INSERT CWGroup X: X name "cubicwebdevelopers"')
@@ -467,10 +478,11 @@ class TicketTC(TrackerBaseTC):
         self.commit()
         self.t1.set_relations(done_in=self.v)
         # -  change ticket status
-        self.t1.fire_transition('done')
+        t1iwf= self.t1.cw_adapt_to('IWorkflowable')
+        t1iwf.fire_transition('done')
         self.t1.clear_all_caches()
         self.v.clear_all_caches()
-        self.assertEquals(self.t1.state, 'done')
+        self.assertEquals(t1iwf.state, 'done')
         # -  Remove permission on the ticket for the clients
         self.execute('DELETE X require_permission P WHERE X eid %s' % self.t1.eid)
         self.commit()
@@ -478,10 +490,11 @@ class TicketTC(TrackerBaseTC):
         self.login('prj1client')
         v2 =  self.execute('Any X WHERE X version_of P, P name "cubicweb", P is Project, X num "0.0.0"').get_entity(0, 0)
         t1 =  self.execute('Any X WHERE X in_state S, S name SN, X eid %s'% self.t1.eid).get_entity(0, 0)
-        self.assertRaises(ValidationError, t1.fire_transition, 'ask validation')
-        v2.fire_transition('publish')
+        t1iwf= t1.cw_adapt_to('IWorkflowable')
+        self.assertRaises(ValidationError, t1iwf.fire_transition, 'ask validation')
+        v2.cw_adapt_to('IWorkflowable').fire_transition('publish')
         # - verify that ticket on which permissions were revoked remains in state
-        self.assertEquals(t1.state, 'done')
+        self.assertEquals(t1iwf.state, 'done')
 
 
 class CommentTC(AutoPopulateTest):
@@ -497,13 +510,28 @@ class CommentTC(AutoPopulateTest):
             if etype == 'TestInstance':
                 continue
             eid = self.execute('Any X LIMIT 1 WHERE X is %s' % etype)[0][0]
-            comment = self.entity('INSERT Comment C: C content "a comment", C comments X WHERE X eid %(x)s',
-                                  {'x': eid})
+            comment = self.execute('INSERT Comment C: C content "a comment", C comments X WHERE X eid %(x)s',
+                                  {'x': eid}).get_entity(0, 0)
             try:
                 comment.project
             except AttributeError:
                 self.fail('%s class does not implement the project property' % etype)
 
+class FTITC(TrackerBaseTC):
+    """Version"""
+    config = ApptestConfiguration('data', sourcefile='sources_fti')
+    
+    def test_entity_weight(self):
+        comment = self.request().create_entity('Comment',
+                                               content=u'cubicweb comment')
+        ticket = self.request().create_entity('Ticket',
+                                              title=u'bug in cubicweb',
+                                              reverse_comments=comment,
+                                              concerns=self.cubicweb)
+        self.commit()
+        self.assertEquals(self.request().execute('Any X ORDERBY FTIRANK(X) DESC WHERE X has_text "cubicweb"').rows,
+                          [[self.cubicweb.eid], [ticket.eid], [comment.eid]])
+
 
 if __name__ == '__main__':
     unittest_main()
