@@ -93,9 +93,7 @@ _pvs.tag_attribute(('License', 'url'), 'hidden')
 _abaa = uicfg.actionbox_appearsin_addmenu
 _abaa.tag_object_of(('*', 'for_version', '*'), False)
 
-# File will be autocasted to Image when necessary, so only provide one link to
-# add an attachment
 _abaa.tag_subject_of(('Ticket', 'attachment', 'File'), True)
-_abaa.tag_subject_of(('Ticket', 'attachment', 'Image'), False)
-for et in ('Ticket', 'Version', 'Image'):
-    _abaa.tag_object_of((et, 'filed_under', 'Folder'), False)
+
+_abaa.tag_object_of(('Ticket', 'filed_under', 'Folder'), False)
+_abaa.tag_object_of(('Version', 'filed_under', 'Folder'), False)
