@@ -9,13 +9,37 @@ __docformat__ = "restructuredtext en"
 from logilab.mtconverter import xml_escape
 
 from cubicweb.schema import display_name
-from cubicweb.selectors import implements, score_entity
+from cubicweb.selectors import is_instance, score_entity
+from cubicweb.view import EntityAdapter
 from cubicweb.web import box, htmlwidgets
 from cubicweb.web.views import idownloadable, boxes
 
+class VersionIDownloadableAdapter(EntityAdapter):
+    __regid__ = 'IDownloadable'
+    __select__ = (is_instance('Version') &
+                  score_entity(lambda x: x.project.downloadurl and x.cw_adapt_to('IWorkflowable').state == 'published'))
+
+    def download_url(self):
+        downloadurl = self.entity.project.downloadurl
+        if not downloadurl:
+            return
+        if not downloadurl[-1] == '/':
+            downloadurl +=  '/'
+        return '%s%s' % (downloadurl, self.entity.tarball_name())
+
+    def download_file_name(self):
+        return self.entity.tarball_name()
+
+    def download_content_type(self):
+        return 'application/x-tar'
+
+    def download_encoding(self):
+        return 'gzip'
+
+
 class ProjectDownloadBox(box.EntityBoxTemplate):
     __regid__ = 'download_box'
-    __select__ = (box.EntityBoxTemplate.__select__ & implements('Project') &
+    __select__ = (box.EntityBoxTemplate.__select__ & is_instance('Project') &
                   score_entity(lambda x: x.downloadurl and x.latest_version()))
 
     def cell_call(self, row, col, **kwargs):
@@ -28,27 +52,20 @@ class ProjectDownloadBox(box.EntityBoxTemplate):
                                    version.tarball_name(), footer=footer)
 
 
-class VersionDownloadBox(idownloadable.DownloadBox):
-    __select__ = (box.EntityBoxTemplate.__select__ & implements('Version') &
-                  score_entity(lambda x: x.project.downloadurl and x.state == 'published'))
-
-    def cell_call(self, row, col, title=None, **kwargs):
-        version = self.cw_rset.get_entity(row, col)
-        super(VersionDownloadBox, self).cell_call(row, col, label=version.tarball_name())
-
 
 class ImageSideboxView(boxes.SideBoxView):
     __regid__ = 'sidebox'
-    __select__ = boxes.SideBoxView.__select__ & implements('Image', 'File')
+    __select__ = boxes.SideBoxView.__select__ & is_instance('File')
 
     def call(self, boxclass='sideBox', title=u''):
         self._cw.add_css('cubes.file.css')
         box = htmlwidgets.SideBoxWidget(display_name(self._cw, title), self.__regid__)
         entity = self.cw_rset.get_entity(0, 0)
-        if entity.e_schema == 'Image':
-            file_icon = entity.download_url()+'&small=true'
+        idownloadable = entity.cw_adapt_to('IDownloadable')
+        if idownloadable.download_content_type().startswith('image/'):
+            file_icon = idownloadable.download_url(small='true')
         else:
-            file_icon =  self._cw.external_resource('FILE_ICON')
+            file_icon =  self._cw.uiprops['FILE_ICON']
 
         if getattr(entity, 'reverse_screenshot', None):
             gallery_url = '%s/?tab=screenshots_tab&selected=%s' % (
