@@ -46,7 +46,7 @@ class FileIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
                 return path
         if entity.project:
             project = entity.reverse_screenshot[0]
-            path = project.breadcrumbs(view, True)
+            path = project.cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
             if entity.reverse_documented_by:
                 url = '%s/%s' % (entity.project.absolute_url(), 'documentation')
                 label = entity._cw._('documentation')
@@ -66,7 +66,7 @@ class CardIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     def breadcrumbs(self, view=None, recurs=False):
         entity = self.entity
         if entity.project:
-            path = entity.project.breadcrumbs(view, True)
+            path = entity.project.cw_adapt_to('IBreadCrumbs').breadcrumbs(view, True)
             if entity.reverse_documented_by:
                 url = '%s/%s' % (entity.project.absolute_url(), 'documentation')
                 path.append( (url, self._cw._('documentation')) )
